
//
#include <ice/ice.h>
#include "MVAPLdap.h"

using namespace std;
using namespace Ice;
using namespace MVAPLdap;


void
usage()
{
	cout << flush;
	cout<<endl;
    cerr << "Usage: " << "command" << " [options] [command...]\n";
    cerr <<        
        "Options:\n"
        "-h, --help           Show this message.\n"
        "\n"
        "Commands:\n"
        "addldap\n                                "
		"modifyldap\n                             "
		"deleteldap\n                             "
		"enumldape\n                              "
		"exit                   Exit the program.\n"
        ;
}


int
run(int argc, char* argv[],const Ice::CommunicatorPtr& communicator)
{

////////////////----- LDAP

	PropertiesPtr properties = communicator->getProperties();
	
    const char* proxyProperty = "LdapProxy.Proxy";
    std::string proxy = properties->getProperty(proxyProperty);
    if(proxy.empty())
    {
		cerr << argv[0] << ": property `" << proxyProperty << "' not set" << endl;
		return EXIT_FAILURE;
    }
	
    ObjectPrx base = communicator->stringToProxy(proxy);
	LDAPProxyPrx depository = LDAPProxyPrx::checkedCast(base);
	
	if (!depository)
    {
		cerr << argv[0] << ": property `" << proxyProperty << "' not set" << endl;
		return EXIT_FAILURE;
    }
//////////////////
    string command;
	string tmp;
	usage();
    do
    {
		try
		{
			cout << "==>";
			cin >> command;
			transform(command.begin(), command.end(), command.begin(), ::tolower);
			//
			if ( command == "addldap" )
			{
				depository->test();
			}
			//--help
			else if(command=="-h")
				usage();
			else if(command!="exit")
				cout<<"command error,input \"-h\" for help"<<endl;
		}
		catch(const Ice::Exception& ex)
		{
			cerr << ex << endl;
		}
    }
    while(cin.good() && command != "exit");


    return EXIT_SUCCESS;
}

int
main(int argc, char* argv[])
{
	int status;
    Ice::CommunicatorPtr communicator;

    try
    {
	Ice::PropertiesPtr properties = Ice::createProperties(argc, argv);
        properties->load("config");
	communicator = Ice::initializeWithProperties(argc, argv, properties);
	status = run(argc, argv, communicator);
    }
    catch(const Ice::Exception& ex)
    {
	cerr << ex << endl;
	status = EXIT_FAILURE;
    }

    if(communicator)
    {
	try
	{
	    communicator->destroy();
	}
	catch(const Ice::Exception& ex)
	{
	    cerr << ex << endl;
	    status = EXIT_FAILURE;
	}
    }

    return status;
}



